chatter.test_utils.test_app package — django-chats 0.1.1 documentation

# chatter.test_utils.test_app package

## Subpackages

- chatter.test_utils.test_app.migrations package
  - Module contents

## Submodules

## chatter.test_utils.test_app.admin module

## chatter.test_utils.test_app.apps module

class `chatter.test_utils.test_app.apps.` `TestAppConfig`(app_name, app_module)

  Bases: `django.apps.config.AppConfig`

  `name` = 'test_app'

## chatter.test_utils.test_app.models module

## Module contents